==> shared_package_flutter-0.0.20.tar.gz: lib/components/list/list_select_search.dart <==
import 'package:flutter/material.dart';

class ListSelectSearchParams{
  final String title;
  Function( String ) _childWithFilter;

  ListSelectSearchParams(
    this.title,
    this._childWithFilter
  );
}

class ListSelectSearch extends StatefulWidget{
  @override
  _ListSelectSearch createState() => _ListSelectSearch();
}

class _ListSelectSearch extends State<ListSelectSearch>{
  ListSelectSearchParams _param;

  // State
  String filter = "";

  @override
  Widget build( BuildContext context ){

    Object obj = ModalRoute.of( context ).settings.arguments;
    if( null != obj && obj.runtimeType == ListSelectSearchParams ){
      _param = obj as ListSelectSearchParams;
    }
    else{

      return Scaffold(
        backgroundColor: Colors.grey,
        body: Center(
          child: Text(
            "Erro ao abrir a tela de pesquisa, parametros não informado",
            style: TextStyle( fontSize: 20 )
          )
        )
      );
    }

    return Scaffold(
      backgroundColor: Colors.grey,
      appBar: AppBar(
        title: Text( _param.title ),
      ),
      body: SingleChildScrollView(
        child: Center(
          child:
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Container(
                  margin: EdgeInsets.only( top: 0.0 ),
                  width: double.infinity,
                  child: listSelect( context )
                )
              ],
            )
        )
      )
    );
  }

  Widget listSelect( BuildContext _context ) {
    final Size screenSize = MediaQuery.of( _context ).size;
    TextEditingController _textEditFilter = TextEditingController();
    _textEditFilter.text = filter;
    _textEditFilter.selection = TextSelection.collapsed( int: _textEditFilter.text.length );

    return SingleChildScrollView(
      child: Padding(
        padding: EdgeInsets.only( top: 45.0 ),
        child: Stack(
          children: <Widget>[
            Container(
              padding: const EdgeInsets.only( top: 50, left: 10, right: 10 ),
              height: screenSize.height - 220,
              width: screenSize.width,
              child: Container(
                padding: const EdgeInsets.only( top: 50, left: 10, right: 10 ),
                height: screenSize.height - 150,
                child: Card(
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular( 12.0 ),
                  ),
                  elevation: 10.0,
                  child: Padding(
                    padding: const EdgeInsets.all( 16.0 ),
                    child: _param._childWithFilter( filter )
                  ),
                ),
              ),
            ),
            Positioned(
              top: 35.0,
              left: 25.0,
              right: 25.0,
              child: AppBar(
                leading: Container(),
                backgroundColor: Colors.white,
                title: TextField(
                  controller: _textEditFilter,
                  decoration: InputDecoration(
                    hintText: "Buscar",
                    border: InputBorder.none,
                    hintStyle: TextStyle( color: Colors.grey )
                  ),
                  onChanged: ( text ) {
                    setState(() {
                      filter = text;
                    });
                  },
                ),
                actions: <Widget>[
                  IconButton(
                    icon: Icon(
                      filter.length == 0 ? Icons.search : Icons.close,
                    color: Colors.black ),
                    onPressed: () {
                      if( filter.length > 0 ){
                        setState(() {
                          filter = "";
                        });
                      }
                    }
                  ),
                ],
              ),
            )
          ],
        )
      )
    );
  }
}

==> shared_package_flutter-0.0.21.tar.gz: lib/components/list/list_select_search.dart <==
import 'package:flutter/material.dart';

class ListSelectSearchParams{
  final String title;
  Function( String ) _childWithFilter;

  ListSelectSearchParams(
    this.title,
    this._childWithFilter
  );
}

class ListSelectSearch extends StatefulWidget{
  @override
  _ListSelectSearch createState() => _ListSelectSearch();
}

class _ListSelectSearch extends State<ListSelectSearch>{
  ListSelectSearchParams _param;

  // State
  String filter = "";

  @override
  Widget build( BuildContext context ){

    Object obj = ModalRoute.of( context ).settings.arguments;
    if( null != obj && obj.runtimeType == ListSelectSearchParams ){
      _param = obj as ListSelectSearchParams;
    }
    else{

      return Scaffold(
        backgroundColor: Colors.grey,
        body: Center(
          child: Text(
            "Erro ao abrir a tela de pesquisa, parametros não informado",
            style: TextStyle( fontSize: 20 )
          )
        )
      );
    }

    return Scaffold(
      backgroundColor: Colors.grey,
      appBar: AppBar(
        title: Text( _param.title ),
      ),
      body: SingleChildScrollView(
        child: Center(
          child:
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Container(
                  margin: EdgeInsets.only( top: 0.0 ),
                  width: double.infinity,
                  child: listSelect( context )
                )
              ],
            )
        )
      )
    );
  }

  Widget listSelect( BuildContext _context ) {
    final Size screenSize = MediaQuery.of( _context ).size;
    TextEditingController _textEditFilter = TextEditingController();
    _textEditFilter.text = filter;
    // Marca o cursor no final
    _textEditFilter.selection = TextSelection.fromPosition( TextPosition( offset: _textEditFilter.text.length ) );
    //_textEditFilter.selection = TextSelection.collapsed( int: _textEditFilter.text.length );

    return SingleChildScrollView(
      child: Padding(
        padding: EdgeInsets.only( top: 45.0 ),
        child: Stack(
          children: <Widget>[
            Container(
              padding: const EdgeInsets.only( top: 50, left: 10, right: 10 ),
              height: screenSize.height - 220,
              width: screenSize.width,
              child: Container(
                padding: const EdgeInsets.only( top: 50, left: 10, right: 10 ),
                height: screenSize.height - 150,
                child: Card(
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular( 12.0 ),
                  ),
                  elevation: 10.0,
                  child: Padding(
                    padding: const EdgeInsets.all( 16.0 ),
                    child: _param._childWithFilter( filter )
                  ),
                ),
              ),
            ),
            Positioned(
              top: 35.0,
              left: 25.0,
              right: 25.0,
              child: AppBar(
                leading: Container(),
                backgroundColor: Colors.white,
                title: TextField(
                  controller: _textEditFilter,
                  decoration: InputDecoration(
                    hintText: "Buscar",
                    border: InputBorder.none,
                    hintStyle: TextStyle( color: Colors.grey )
                  ),
                  onChanged: ( text ) {
                    setState(() {
                      filter = text;
                    });
                  },
                ),
                actions: <Widget>[
                  IconButton(
                    icon: Icon(
                      filter.length == 0 ? Icons.search : Icons.close,
                    color: Colors.black ),
                    onPressed: () {
                      if( filter.length > 0 ){
                        setState(() {
                          filter = "";
                        });
                      }
                    }
                  ),
                ],
              ),
            )
          ],
        )
      )
    );
  }
}
